import { world, system } from "@minecraft/server";

// Define a cooldown map to prevent spamming
const playerCooldowns = new Map();

// Listen for player right-click interactions
world.afterEvents.playerInteractWithBlock.subscribe(event => {
    const { player, block, itemStack } = event;

    // Ensure the player is holding an item
    if (!itemStack) return;

    // Get the block location and type
    const { x, y, z } = block.location;
    const blockType = block.permutation.type.id;

    // Prevent replacing air or unbreakable blocks
    if (blockType === "minecraft:air") return;

    // Check if the block has the custom component for replaceable blocks
    if (!block.hasComponent("custom:replaceable_block")) return;

    // Check player cooldown
    const currentTime = system.currentTick;
    if (playerCooldowns.get(player.id) > currentTime) return;

    // Set cooldown (e.g., 20 ticks = 1 second)
    playerCooldowns.set(player.id, currentTime + 20);

    // Replace the block with the one the player is holding
    const newBlockType = itemStack.typeId;
    player.dimension.getBlock({ x, y, z }).setType(newBlockType);

    // Reduce item count in hand (if not in creative mode)
    if (!player.isOp()) {
        const inventory = player.getComponent("minecraft:inventory");
        if (inventory) {
            let container = inventory.container;
            let slot = player.selectedSlot;
            let item = container.getItem(slot);
            if (item) {
                item.amount -= 1;
                container.setItem(slot, item.amount > 0 ? item : undefined);
            }
        }
    }
});
